qtmobileextensions/src/systemtoneservice/xqsystemtoneservice.h
changeset 19 46686fb6258c
parent 8 71781823f776
--- a/qtmobileextensions/src/systemtoneservice/xqsystemtoneservice.h	Tue Jul 06 15:12:50 2010 +0300
+++ b/qtmobileextensions/src/systemtoneservice/xqsystemtoneservice.h	Wed Aug 18 10:38:12 2010 +0300
@@ -139,7 +139,7 @@
 /**
 * Play selected alarm. 
 *
 * @param  toneType  selected tone type.
 * @param  contextId  unique playback id for current playback event. May be used for matching playback signals and/or to later stop playing.
 * @see  XQSystemToneService::stopAlarm(unsigned int contextId)
 * @see  XQSystemToneService::error()
@@ -155,6 +155,16 @@
 */
   STS_EXPORT void stopAlarm(unsigned int contextId);
 
+/**
+* Play selected tone. 
+*
+* @param  toneType  selected tone type.
+* @param  contextId  unique playback id for current playback event. May be used for matching playback signals and/or to later stop playing.
+* @see  XQSystemToneService::stopAlarm(unsigned int contextId)
+* @see  XQSystemToneService::error()
+*/
+  STS_EXPORT void playAlarm(ToneType toneType, unsigned int& contextId);
+  
 signals:
 
 /**
@@ -139,7 +139,7 @@
 * Play selected alarm. 
 *
-* @param  toneType  selected tone type.
+* @param  alarmType  selected tone type.
 * @param  contextId  unique playback id for current playback event. May be used for matching playback signals and/or to later stop playing.
 * @see  XQSystemToneService::stopAlarm(unsigned int contextId)